@@ -15,11 +15,9 @@ class EasyCache:
         def func_decorator(func):
             @wraps(func)
             async def wrapped_function(*args, **kw):
-                logger.info('find 1')
                 param, eil = self.__get_param(key_param_index, key_param_name, *args, **kw)
                 if eil:
                     logger.warning(eil)
-                    logger.info('find 2')
                     return await self.__run_func(func, *args, **kw)
                 if opt_param2key_func:
                     key = opt_param2key_func(param)
@@ -27,23 +25,19 @@ class EasyCache:
                         logger.warning(f'opt_param2key_func:{opt_param2key_func.__name__}'
                                        f' should return a primary key of string type'
                                        )
-                        logger.info('find 3')
                         return await self.__run_func(func, *args, **kw)
                 else:
                     key, eil = self.__default_param2key_func(param, prefix)
                     if eil:
                         logger.warning(eil)
-                        logger.info('find 4')
                         return await self.__run_func(func, *args, **kw)
                 logger.info(f'redis key is : {key}')
                 current_redis = redis if redis else self.default_redis
                 response, ok = await self.__find_in_redis(key, current_redis)
                 if ok:
-                    logger.info('find 5')
                     return ujson.loads(response)
                 response = await self.__run_func(func, *args, **kw)
                 await self.__add_cache(key, key_expire_time, response, current_redis)
-                logger.info('find 6')
                 return response
             return wrapped_function
         return func_decorator
@@ -100,10 +94,8 @@ class EasyCache:
 
     async def __run_func(self, func, *args, **kw):
         if asyncio.iscoroutinefunction(func):
-            logger.info('find run func 1')
             return await func(*args, **kw)
         else:
-            logger.info('find run func 2')
             return func(*args, **kw)
 
     def __default_param2key_func(self, param, prefix):
